# aidash-ds-utils

AiDash utilities for geospatial data science. Includes functions for:
    1. prioritizing and clipping overlapping geospatial masks

## Installation

```bash
pip install aidash-ds-utils
